@@ -1,17 +1,17 @@
-# Copyright (C) 2021 Brodie Gaslam
-# 
-# This file is part of "unitizer"
-# 
+# Copyright (C) Brodie Gaslam
+#
+# This file is part of "unitizer - Interactive R Unit Tests"
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
 
 #' @include item.R
@@ -233,14 +233,6 @@ setMethod("bookmarked", "unitizerObjectList", function(x, ...) {
       is(y, "unitizer") && is(y@bookmark, "unitizerBrowseBookmark"),
     logical(1L)
   )
-  if(!length(which(bookmarked)) %in% 0:1) {
-    # nocov start
-    stop(
-      "Internal Error: no more than one unitizer may be bookmarked at any ",
-      "given time; contact maintainer"
-    )
-    # nocov end
-  }
   bookmarked
 } )
 # Keeps track of All Test Review Data
